function _extends() {
  _extends = Object.assign ? Object.assign.bind() : function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];
      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }
    return target;
  };
  return _extends.apply(this, arguments);
}

var omit = function omit(o, key) {
  return Object.fromEntries(Object.entries(o).filter(function (e) {
    return e[0] !== key;
  }));
};
var omitMultiple = function omitMultiple(o, keys) {
  var exclude = new Set(keys);
  return Object.fromEntries(Object.entries(o).filter(function (e) {
    return !exclude.has(e[0]);
  }));
};

var SIMPLE_REDUX_FIELD__OPEN = 'SIMPLE_REDUX_FIELD__OPEN';
var SIMPLE_REDUX_FIELD__CLOSE = 'SIMPLE_REDUX_FIELD__CLOSE';
var SIMPLE_REDUX_FIELD__OPEN_MULTIPLE = 'SIMPLE_REDUX_FIELD__OPEN_MULTIPLE';
var SIMPLE_REDUX_FIELD__CLOSE_MULTIPLE = 'SIMPLE_REDUX_FIELD__CLOSE_MULTIPLE';
var initialState = {};
var simpleReduxFieldReducer = function simpleReduxFieldReducer(state, action) {
  if (state === void 0) {
    state = initialState;
  }
  var payload = action.payload;
  switch (action.type) {
    case SIMPLE_REDUX_FIELD__OPEN:
      return openCase(state, payload);
    case SIMPLE_REDUX_FIELD__CLOSE:
      return closeCase(state, payload);
    case SIMPLE_REDUX_FIELD__OPEN_MULTIPLE:
      return openMultipleCase(state, payload);
    case SIMPLE_REDUX_FIELD__CLOSE_MULTIPLE:
      return closeMultipleCase(state, payload);
    default:
      return state;
  }
};
var openCase = function openCase(state, payload) {
  var _extends2;
  return _extends({}, state, (_extends2 = {}, _extends2[payload.key] = payload.value, _extends2));
};
var closeCase = function closeCase(state, payload) {
  return omit(state, payload.key);
};
var openMultipleCase = function openMultipleCase(state, payload) {
  var fields = payload.reduce(function (acc, curr) {
    var _extends3;
    return _extends({}, acc, (_extends3 = {}, _extends3[curr.key] = curr.value, _extends3));
  }, {});
  return _extends({}, state, fields);
};
var closeMultipleCase = function closeMultipleCase(state, payload) {
  return omitMultiple(state, payload);
};
var openAction = function openAction(key, value) {
  return {
    type: SIMPLE_REDUX_FIELD__OPEN,
    payload: {
      key: key,
      value: value
    }
  };
};
var closeAction = function closeAction(key) {
  return {
    type: SIMPLE_REDUX_FIELD__CLOSE,
    payload: {
      key: key
    }
  };
};
var openMultipleAction = function openMultipleAction(values) {
  return {
    type: SIMPLE_REDUX_FIELD__OPEN_MULTIPLE,
    payload: values
  };
};
var closeMultipleAction = function closeMultipleAction(keys) {
  return {
    type: SIMPLE_REDUX_FIELD__CLOSE_MULTIPLE,
    payload: keys
  };
};
var openField = function openField(key, value) {
  return function (dispatch) {
    dispatch(openAction(key, value));
  };
};
var closeField = function closeField(key) {
  return function (dispatch) {
    dispatch(closeAction(key));
  };
};
var openFields = function openFields(values) {
  return function (dispatch) {
    dispatch(openMultipleAction(values));
  };
};
var closeFields = function closeFields(keys) {
  return function (dispatch) {
    dispatch(closeMultipleAction(keys));
  };
};

export { closeField, closeFields, openField, openFields, simpleReduxFieldReducer };
//# sourceMappingURL=index.modern.js.map
